require 'remenv/config'
require 'fileutils'

describe Remenv::Config do
  after do
    FileUtils.rm('.remenv.yml', force: true)
  end

  it 'loads default settings from the current directory' do
    hash = { url: 'cache.com:6329/0', namespace: 'cache-env' }

    File.open('.remenv.yml', 'w') do |file|
      Psych.dump({ 'development' => hash }, file)
    end

    expect(Remenv::Config.load).to eq(hash)
  end

  it 'loads environment specific settings when provided' do
    staging = { url: 'cache.com:6329/0', namespace: 'cache-env' }

    File.open('.remenv.yml', 'w') do |file|
      Psych.dump({ staging: staging }, file)
    end

    expect(Remenv::Config.load(stage: :staging)).to eq(staging)
  end

  it 'falls back to an empty hash without a config' do
    expect(Remenv::Config.load).to eq({})
  end
end
