require 'remenv/io'
require 'fileutils'

describe Remenv::IO do
  let(:adapter) { Remenv::Adapter::Memory.new }

  describe '#write' do
    it 'writes the current configuration to an io object' do
      handle = StringIO.new
      io     = Remenv::IO.new(adapter)

      adapter.set(key1: 'a', key2: 'b')
      io.write(handle, leader: 'export')

      expected = <<-DATA.gsub(/^\s+/, '')
        export key1="a"
        export key2="b"
      DATA

      expect(handle.read).to eq(expected)
    end
  end

  describe '#read' do
    it 'reads configuration from an io object' do
      handle = StringIO.new("key1=a\nkey2=b\n")

      io = Remenv::IO.new(adapter)
      io.read(handle)

      expect(adapter.show).to eq(
        'key1' => 'a',
        'key2' => 'b'
      )
    end

    it 'ignores export statements and whitespace' do
      handle = StringIO.new(%(export key1 = a\n\n# comment\nEXPORT key2 = 'b'\nexport key3="c"))

      io = Remenv::IO.new(adapter)
      io.read(handle)

      expect(adapter.show).to eq(
        'key1' => 'a',
        'key2' => 'b',
        'key3' => 'c'
      )
    end
  end

  describe '#load' do
    let(:filename) { 'vars.env' }

    after do
      FileUtils.rm(filename, force: true)
    end

    it 'clears any existing stored configuration' do
      File.open(filename, 'w') do |file|
        file << 'export key2="b"'
      end

      adapter.set(key1: 'a')
      io = Remenv::IO.new(adapter)
      io.load(filename)

      expect(adapter.show).to eq('key2' => 'b')
    end
  end
end
