require 'fileutils'

describe Remenv do
  after do
    Remenv.adapter = nil
    Remenv.clear!
  end

  describe '.adapter' do
    it 'defaults to an in-memory adapter' do
      expect(Remenv.adapter).to be_instance_of(Remenv::Adapter::Memory)
    end

    it 'can be overridden to use a custom adapter' do
      adapter = double(:adapter)

      Remenv.adapter = adapter

      expect(Remenv.adapter).to be(adapter)
    end
  end

  describe '.configure' do
    it 'allows interaction with the module' do
      adapter = double(:adapter)

      Remenv.configure do |remenv|
        remenv.adapter = adapter
      end

      expect(Remenv.adapter).to be(adapter)
    end
  end

  describe '.set' do
    it 'stores each key and value' do
      pairs = { 'RACK_ENV' => 'production', 'PORT' => '3000' }

      Remenv.set(pairs)

      expect(Remenv.show).to eq(pairs)
    end
  end

  describe '.unset' do
    it 'clears the provided keys' do
      Remenv.set(KEY1: 1, KEY2: 2, KEY3: 3)
      Remenv.unset('KEY1', 'KEY3')

      expect(Remenv.show).to eq('KEY2' => '2')
    end
  end

  describe '.get' do
    it 'retrieves the value at the provided key' do
      Remenv.set('PORT' => '3000')

      expect(Remenv.get('PORT')).to eq('3000')
    end
  end
end
